{% block debug_content %}
    {% if debug_info %}
        <div class="accordion" id="accordion2">
            <div class="accordion-group">
                <div class="accordion-heading">
                    <a class="accordion-toggle" data-toggle="collapse" data-parent="#accordion2"
                       href="#collapseMeta">
                        <pre>request.META</pre>
                    </a>
                </div>
                <div id="collapseMeta" class="accordion-body collapse">
                    <div class="accordion-inner">
                    <pre>
                        {{ debug_info.meta }}
                    </pre>
                    </div>
                </div>
            </div>
            <div class="accordion-group">
                <div class="accordion-heading">
                    <a class="accordion-toggle" data-toggle="collapse" data-parent="#accordion2"
                       href="#collapseUser">
                        <pre>request.user</pre>
                    </a>
                </div>
                <div id="collapseUser" class="accordion-body collapse">
                    <div class="accordion-inner">
                    <pre>
                        {{ debug_info.user }}
                    </pre>
                    </div>
                </div>
            </div>
            <div class="accordion-group">
                <div class="accordion-heading">
                    <a class="accordion-toggle" data-toggle="collapse" data-parent="#accordion2"
                       href="#collapseEnviron">
                        <pre>os.environ</pre>
                    </a>
                </div>
                <div id="collapseEnviron" class="accordion-body collapse">
                    <div class="accordion-inner">
                    <pre>
                        {{ debug_info.environ }}
                    </pre>
                    </div>
                </div>
            </div>
        </div>
    {% endif %}
{% endblock %}