{% if status == 'new' %}
    <span>
{% elif status == 'uploaded' %}
    <span class='btn btn-mini btn-info'>
    <i class='icon-upload'></i>
{% elif status == 'unpacking' %}
    <span class='btn btn-mini btn-primary'>
    <i class='icon-refresh'></i>
{% elif status == 'deployed' %}
    <span class='btn btn-mini btn-success'>
    <i class='icon-ok'></i>
{% elif status == 'cancelled' %}
    <span class='btn btn-mini btn-warning'>
    <i class='icon-warning-sign'></i>
{% elif status == 'undeployed' %}
    <span class='btn btn-mini btn-warning'>
    <i class='icon-trash'></i>
{% elif status == 'deleted' %}
    <span class="btn btn-mini btn-danger">
    <i class='icon-trash'></i>
{% elif status == 'error' %}
    <span class="btn btn-mini btn-danger">
    <i class='icon-fire'></i>
{% else %}
    <span>
{% endif %}
    {{ status }}
</span>