{% load staticfiles %}
{% block extra_head %}
{% endblock extra_head %}

<div class="accordion" id="accordion-{{ uid }}">
    <div class="accordion-group">
        <div class="accordion-heading">
            <a class="accordion-toggle" data-toggle="collapse" data-parent="#accordion2"
               href="#collapseProject{{ project.id }}">
                {{ name }}
            </a>
        </div>
        <div id="collapseProject{{ project.id }}" class="accordion-body collapse in">
            <div class="accordion-inner">
                <div class='tree well'>
                    <a class='btn btn-mini expand_all' title='expand all branches'><i class='icon-plus'></i></a>
                    <a class='btn btn-mini collapse_all' title='collapse all branches'><i class='icon-minus'></i></a>
                    <a class='btn btn-mini' title='deploy package' href='{% url 'projects:deploy' project.id '.' %}'><i class='icon-download-alt'></i>deploy</a>
                    <a class='btn btn-mini' title='make directory' href='{% url 'projects:mkdir' project.id '.' %}'><i class='icon-plus-sign'></i>mkdir</a>
                    {% include 'tree/_tree.html' with subfiles=files %}
                </div>
            </div>
        </div>
    </div>
</div>