.mkdir form span.path, .rmdir form span.path, .deploy form span.path
  cursor: pointer
  -moz-border-radius: 5px
  -webkit-border-radius: 5px
  border-radius: 5px
  display: inline-block
  padding: 0 3px 0 3px
  text-decoration: none
  background: #eeeeee
  border: 1px solid #94a0b4
  color: black

.mkdir form span.path:hover, .rmdir form span.path:hover, .deploy form span.path:hover
  background: #eeeeee
  border: 1px solid #94a0b4
  color: black