.dl-unwrapped-horizontal dt {
  white-space: normal; }

.lesser-hero-unit {
  padding-top: 10px;
  padding-bottom: 10px;
  margin-bottom: 10px; }

.monospaced {
  font-family: Consolas, Lucida Console, monospace; }
