.tree {
  display: none;
  min-height: 20px;
  padding: 19px;
  margin-bottom: 20px;
  background-color: #fbfbfb;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05);
  -moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05); }
  .tree li {
    list-style-type: none;
    margin: 0;
    padding: 0px 5px 0 5px;
    position: relative; }
    .tree li::before, .tree li::after {
      content: "";
      left: -15px;
      position: absolute;
      right: auto; }
    .tree li::before {
      border-left: 1px solid #999999;
      bottom: 50px;
      height: 100%;
      top: 0;
      width: 1px; }
    .tree li::after {
      border-top: 1px solid #999999;
      height: 20px;
      top: 10px;
      width: 20px; }
    .tree li span {
      -moz-border-radius: 5px;
      -webkit-border-radius: 5px;
      border: 1px solid transparent;
      border-radius: 5px;
      display: inline-block;
      padding: 0 3px 0 3px;
      text-decoration: none; }
      .tree li span.actions {
        visibility: hidden; }
    .tree li.parent_li > span.folder {
      cursor: pointer; }
    .tree li:last-child::before {
      height: 15px; }
    .tree li.parent_li > span.folder:hover {
      background: #eeeeee;
      border: 1px solid #94a0b4;
      color: black; }
      .tree li.parent_li > span.folder:hover > span.actions {
        background: #eeeeee;
        border: 1px solid transparent;
        color: black;
        visibility: visible; }
    .tree li > span.file:hover > span.actions {
      visibility: visible; }
  .tree > ul > li::before, .tree > ul > li::after {
    border: 0; }

.mkdir form span.path, .rmdir form span.path, .deploy form span.path {
  cursor: pointer;
  -moz-border-radius: 5px;
  -webkit-border-radius: 5px;
  border-radius: 5px;
  display: inline-block;
  padding: 0 3px 0 3px;
  text-decoration: none;
  background: #eeeeee;
  border: 1px solid #94a0b4;
  color: black; }

.mkdir form span.path:hover, .rmdir form span.path:hover, .deploy form span.path:hover {
  background: #eeeeee;
  border: 1px solid #94a0b4;
  color: black; }
