{#{% for file in files %}#}
{#    <li>#}
{#                {{ file }}#}
{#        </li>#}
{#        <span class='file'>#}
{#            <span class='name'>#}
{#                <i class='icon-file'></i>#}
{#                {{ file }}#}
{#            </span>#}
{#            <span class='actions'>#}
{#                <a href='{% url 'projects:rm' project_id path %}'><i class='icon-trash'></i></a>#}
{#            </span>#}
{#        </span>#}
{#    </li>#}
{#{% endfor %}#}
{% if pre %}
    <li>
        <pre>{{ files }}</pre>
    </li>
{% else %}
    {% for file in files %}
        <li>
            <span class='file'>
                <span class='name'>
                    <i class='icon-file'></i>
                    {{ file }}
                </span>
                <span class='actions'>
                    <a title="remove file" href='{% url 'projects:rm' project_id path|add:'/'|add:file %}'><i class='icon-trash'></i></a>
                </span>
            </span>
        </li>
    {% endfor %}
{% endif %}

