{% extends 'base.html' %}

{% load bootstrap_toolkit %}

{% block content %}

    <div class='rmdir'>
        <h1>Remove directory</h1>

        {% if error_message %}<p><strong>{{ error_message }}</strong></p>{% endif %}

        <form action='{% url 'projects:rmdir' project_id path %}' class='form' method='post'>
            {% csrf_token %}
            <a href='{% url 'projects:show' project_id path %}'>
                <span class='path monospaced'>
                    {{ path }}
                </span>
            </a>
            {{ form | as_bootstrap }}
            <div class="form-actions">
                <input type="submit" class="btn btn-danger" value="Remove"/>
                <a class='btn' href='{% url 'projects:show' project_id path %}'>Cancel</a>
            </div>
        </form>
    </div>


{% endblock %}
