<ul class="nav">
    <li><a href="{% url 'projects:index' %}" class="">Home</a></li>
    <li><a href="{% url 'projects:index' %}">Packages</a></li>
    <li class="dropdown">
        <a href="#" class="dropdown-toggle" data-toggle="dropdown">Dropdown<b class="caret"></b></a>
        <ul class="dropdown-menu">
            <li><a href="dropdown">Vertical</a></li>
        </ul>
    </li>
</ul>