<li>
    <span class='folder'>
        <span class='name'>
            <i class='icon-folder-close'></i>
            {{ file }}
        </span>
        <span class='actions'>
            {% if can_deploy %}
                <a title='Deploy package' href='{% url 'projects:deploy' project_id path %}'><i class='icon-download-alt'></i></a>
            {% endif %}
            <a title="remove directory" href='{% url 'projects:rmdir' project_id path %}'><i class='icon-trash'></i></a>
            <a title="Make directory" href='{% url 'projects:mkdir' project_id path %}'><i class='icon-plus-sign'></i></a>
        </span>
    </span>
    <ul>
        {% for f in subfiles %}
            {{ f }}
        {% endfor %}
    </ul>
</li>