<div class="accordion" id="accordion-{{ uid }}">
    <div class="accordion-group">
        <div class="accordion-heading">
            <a class="accordion-toggle" data-toggle="collapse" data-parent="#accordion2"
               href="#collapse{{ uid }}">
                {{ name }}
            </a>
        </div>
        <div id="collapse{{ uid }}" class="accordion-body collapse{% if unfolded %}in{% endif %}">
            <div class="accordion-inner">
                <ul class='unstyled monospaced'>
                    {% for file in files %}
                        <li>{{ file }}</li>
                    {% endfor %}
                </ul>
            </div>
        </div>
    </div>
</div>
