{% extends 'base.html' %}

{% load bootstrap_toolkit %}

{% block content %}

    <div class='upload'>
        <h1>Upload new package</h1>

        {% if error_message %}<p><strong>{{ error_message }}</strong></p>{% endif %}

        <form action='{% url 'projects:upload' project_id %}' class='form' method='post'
              {% if form.is_multipart %}enctype='multipart/form-data'{% endif %}>
            {% csrf_token %}
            {{ form | as_bootstrap }}
            <div class="form-actions">
                <input type="submit" class="btn btn-primary" value="Upload"/>
                <a class='btn' href='{% url 'projects:show' project_id %}'>Cancel</a>
            </div>
        </form>
    </div>


{% endblock %}
