{% extends 'base.html' %}

{% load bootstrap_toolkit %}
{% load guardian_tags %}

{% block content %}
    <div class='row'>
        <div class='span9'>
            {% if show_setup_projects or show_setup_admin or show_setup_filesystems %}
                <ul>
                    {% if show_setup_admin %}
                        <li>
                            <a href="{% url 'appsetup:admin' %}">setup admin</a>
                        </li>
                    {% endif %}
                    {% if show_setup_filesystems %}
                        <li>
                            <a href="{% url 'appsetup:filesystems' %}">setup filesystems</a>
                        </li>
                    {% endif %}
                    {% if show_setup_projects %}
                        <li>
                            <a href="{% url 'appsetup:projects' %}">setup projects</a>
                        </li>
                    {% endif %}
                </ul>
            {% endif %}
        </div>
        <div class='span3'>
        </div>
    </div>
{% endblock %}
