<dl class='dl-horizontal'>
    {% for package in packages %}
        <dt>
            {% include 'packages/_status.html' with status=package.status_name %}
        </dt>
        <dd>
            <a href='{% url 'packages:show' package.id %}'>
                {{ package.filepath }}
            </a>
        </dd>
    {% endfor %}
</dl>
